ListPaginated class

Lista (paginada) registros da tabela.

Inheritance

Constructors

ListPaginated(DbModel model, {String orderBy = 'id', bool desc = true})
const

Properties

desc bool
final
hashCode int
The hash code for this object.
no setterinherited
model DbModel
final
orderBy String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited