ApiConfig class

Configuração base aplicada a todas as chamadas (middlewares padrão): CORS, limites de paginação. Pensada para o usuário não precisar configurar.

Constructors

ApiConfig({String corsOrigin = '*', int defaultPerPage = 20, int maxPerPage = 100})
const

Properties

corsOrigin String
final
defaultPerPage int
final
hashCode int
The hash code for this object.
no setterinherited
maxPerPage int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited