Field class

Campo de entrada de um endpoint, com validação declarativa. A mesma regra é aplicada no alvo Dart (runtime) e gerada no PHP.

Constructors

Field(String name, {bool required = false, bool email = false, bool isInt = false, int? maxLength})
const

Properties

email bool
final
hashCode int
The hash code for this object.
no setterinherited
isInt bool
final
maxLength int?
final
name String
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String? value) String?
Retorna a mensagem de erro, ou null se válido.

Operators

operator ==(Object other) bool
The equality operator.
inherited