PageMeta class

Metadados de paginação devolvidos no envelope (meta).

Constructors

PageMeta({required int page, required int perPage, required int total})
const
PageMeta.of(PageRequest req, int total)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasNext bool
no setter
hasPrev bool
no setter
page int
final
perPage int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final
totalPages int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited