PhpApiGenerator class

Stub Web de PhpApiGenerator — geração de arquivos só no servidor.

Constructors

PhpApiGenerator()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(List<ApiEndpoint> endpoints) → Never
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeTo(String dir, List<ApiEndpoint> endpoints, {List<DbModel> models = const []}) → Never

Operators

operator ==(Object other) bool
The equality operator.
inherited