FlenxApp class

Ponto de entrada declarativo do site Flenx.

Constructors

FlenxApp()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

run({required ServerOptions options, required SeoConfig seo, required List<FlenxRoute> routes, required Component notFound, String? blog, Blog? blogInstance, List<BlogSource> blogSources = const [], bool blogFromDb = false, String blogTable = 'blog_posts', BlogLayoutBuilder? blogLayout, List<IRouteSource> extraSources = const [], List<ApiEndpoint> apis = const [], DbExecutor? db, EmailSender? onEmail, TokenVerifier? tokenVerifier, List<FlenxStyle> globalStyles = const [], List<String> rawGlobalStyles = const [], AdsConfig? ads, FlenxTracking? tracking, FlenxConsent? consent, String lang = 'pt-BR', int? port, String? primaryColor, String? primaryColorDark, String? faviconUrl, String? appleTouchIconUrl, List<String> globalScripts = const [], List<Component> floatingButtons = const [], List<String> preloadImages = const [], bool emitHtaccess = true}) Future<void>
Sobe o site com uma única chamada. routes é a fonte única: cada FlenxRoute traz o SEO e o componente. Se blog for informado, /blog* é resolvido sozinho. extraSources adiciona fontes dinâmicas de sitemap.