BlogRepository class
Carrega posts de blog de uma pasta de arquivos .md no filesystem.
Executa apenas no servidor (usa dart:io). O nome do arquivo (sem .md)
é o slug padrão. Posts são ordenados do mais novo para o mais antigo.
Constructors
- BlogRepository({FrontmatterParser parser = const FrontmatterParser(), PostFactory factory = const PostFactory()})
-
const
Properties
- factory → PostFactory
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parser → FrontmatterParser
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
loadAll(
String directory) → Future< List< BlogPost> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited