MarkdownRenderer class

Converte Markdown em HTML (usado para renderizar o corpo dos posts no SSR). Usa o pacote oficial markdown com extensões GitHub-flavored.

Constructors

MarkdownRenderer()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHtml(String markdown) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited