Tag class

Tag de blog — transversal e plana (várias por post), como no WordPress.

Constructors

Tag(String name)

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
final
path → String
Caminho da página de arquivo da tag (ex.: /blog/tag/flutter).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override