PostFactory class

Constrói um BlogPost a partir do conteúdo parseado de um arquivo .md. Isola a leitura do frontmatter (testável sem acessar o disco).

Constructors

PostFactory()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(String slug, ParsedContent content) BlogPost
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited