DynamicBlogRouteSource class

Fonte de rotas SEO do blog que recarrega as fontes a cada resolução. Usada quando há posts em banco (criados pelo admin em runtime): o sitemap/ llms.txt refletem os posts atuais sem reiniciar o servidor.

Implemented types

Constructors

DynamicBlogRouteSource(List<BlogSource> sources)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<BlogSource>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Future<List<RouteMeta>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited