TaxonomyBuilder class

Indexa os posts em categorias e tags, produzindo as páginas de arquivo. Pura (sem disco) → fácil de testar.

Constructors

TaxonomyBuilder()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(List<BlogPost> posts) Taxonomy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited