Slugify class

Converte um texto em slug amigável para URL (minúsculo, sem acentos, hífens no lugar de espaços). Ex.: "Tutoriais Flutter" → "tutoriais-flutter".

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

call(String input) String