SqlMigrationGenerator class

Gera o SQL de criação das tabelas (MySQL) a partir dos DbModel, incluindo chaves primárias e estrangeiras (relações). Roda uma vez.

Constructors

SqlMigrationGenerator()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(List<DbModel> models) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited