JasprBadge class

A "Built with Jaspr" badge component.

Use one of the named constructors to choose a style:

  • JasprBadge.light(): Light background with dark icon and text.
  • JasprBadge.dark(): Dark background with light icon and text.
  • JasprBadge.lightTwoTone(): Light background with blue icon and dark text.
  • JasprBadge.darkTwoTone(): Dark background with blue icon and light text.
Inheritance

Constructors

JasprBadge.dark({Key? key})
Creates a "Built with Jaspr" badge with a dark background, light icon, and light text.
const
JasprBadge.darkTwoTone({Key? key})
Creates a two-tone "Built with Jaspr" badge with a dark background, blue icon, and light text.
const
JasprBadge.light({Key? key})
Creates a "Built with Jaspr" badge with a light background, dark icon, and dark text.
const
JasprBadge.lightTwoTone({Key? key})
Creates a two-tone "Built with Jaspr" badge with a light background, blue icon, and dark text.
const

Properties

backgroundColor → Color
final
hashCode int
The hash code for this object.
no setterinherited
iconColor → Color
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited