ChannelResult class

Resultado do envio por um canal.

Constructors

ChannelResult(String channel, bool ok, [String? error])
const

Properties

channel String
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
ok bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited