NotificationChannel class abstract interface

Um meio de notificação (push, SMS, WhatsApp, e-mail...). Implemente para adicionar canais. enabled indica se está configurado/ativo.

Implementers

Properties

enabled bool
Ativo? (ex.: credenciais presentes no .env). Só os ativos disparam.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
Nome do canal (ex.: 'twilio-sms', 'fcm').
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(NotificationMessage message) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited