PaymentRequest class

Dados para criar uma cobrança/checkout, independente do provedor.

Constructors

PaymentRequest({required double amount, required String description, required String customerEmail, String? customerName, String? externalReference, String? successUrl, String? failureUrl})
const

Properties

amount → double
Valor em reais (ex.: 49.90).
final
customerEmail → String
final
customerName → String?
final
description → String
final
externalReference → String?
Referência do seu pedido (volta no webhook).
final
failureUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successUrl → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited