PaymentResult class

Resultado de uma criação de checkout.

Constructors

PaymentResult({required String id, required String checkoutUrl, PaymentStatus status = PaymentStatus.pending, Map<String, dynamic> raw = const {}})
const

Properties

checkoutUrl String
URL para redirecionar o cliente e pagar.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Id da cobrança no provedor.
final
raw Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PaymentStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited