SeoAddress class

Endereço físico para schema.org LocalBusiness (PostalAddress + GeoCoordinates).

Constructors

SeoAddress({required String streetAddress, required String addressLocality, String? addressRegion, required String postalCode, String addressCountry = 'BR', double? latitude, double? longitude})
const

Properties

addressCountry String
final
addressLocality String
final
addressRegion String?
final
hasGeo bool
no setter
hashCode int
The hash code for this object.
no setterinherited
latitude double?
final
longitude double?
final
postalCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streetAddress String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited