IRouteSource class abstract interface

Contrato de uma fonte de rotas. Cada fonte sabe produzir a lista de RouteMeta que representa — estáticas ou expandidas de dados dinâmicos.

Resolução é assíncrona porque rotas dinâmicas podem consultar banco/API.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Future<List<RouteMeta>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited