StaticRouteSource class

Fonte de rotas estáticas — páginas fixas conhecidas em tempo de build (home, sobre, contato, etc.). Equivale às páginas do file-based routing.

Implemented types

Constructors

StaticRouteSource(List<RouteMeta> routes)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
routes List<RouteMeta>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Future<List<RouteMeta>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited