JsonUtils class

Utilidades para emissão de JSON-LD.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encode(Map<String, dynamic> data) String
Apenas o JSON (sem a tag script), com < escapado — para usar como content de um elemento script do jaspr.
ldScript(Map<String, dynamic> data) String
Serializa um mapa schema.org em <script type="application/ld+json">. Escapa < como a sequência unicode < para não fechar o bloco <script> prematuramente (recomendação do Google para JSON-LD inline).