XmlUtils class

Utilidades de escape para emissão segura de XML (sitemap).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

escape(String input) String
Escapa os 5 caracteres reservados de XML.
w3cDate(DateTime date) String
Formata uma data no padrão W3C/ISO 8601 (aceito em <lastmod>).