ServerHandler constructor
Creates a new connected pair of a Server with the given url and a
Handler.
The caller is responsible for ensuring that requests to url or any URL
beneath it are handled by handler.
If onClose is passed, it's called when server is closed. It may return
a Future or null; its return value is returned by Server.close.
Implementation
ServerHandler(Uri url, {Future<void>? Function()? onClose})
: _server = _HandlerServer(url, onClose);