EditableBlock class

Estado MUTÁVEL de um bloco enquanto é editado na tela. Cada instância tem um id estável (para ValueKey ao reordenar) e converte para o PostBlock imutável da lib na hora de salvar — e também reconstrói a partir de um PostBlock (para editar um post existente).

Constructors

EditableBlock(int id, BlockType type)
EditableBlock.fromPostBlock(int id, PostBlock block)
Reconstrói um EditableBlock a partir de um PostBlock salvo.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
final
level int
getter/setter pair
ordered bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary String
getter/setter pair
text String
getter/setter pair
type BlockType
getter/setter pair
url String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPostBlock() PostBlock
Converte para o bloco imutável correspondente da lib.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited