PostMetaControllers class

Agrupa os controllers do cabeçalho (1 lugar para criar/dar dispose).

Constructors

PostMetaControllers()

Properties

author TextEditingController
final
category TextEditingController
final
description TextEditingController
final
hashCode int
The hash code for this object.
no setterinherited
image TextEditingController
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle TextEditingController
final
tags TextEditingController
final
title TextEditingController
final

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited