FlenxAdminTheme class

Temas padrão do painel admin do Flenx — claro e escuro, derivados da paleta central FlenxPalette (mesma identidade do site). Bonito por padrão:

MaterialApp(
  theme: FlenxAdminTheme.light(),
  darkTheme: FlenxAdminTheme.dark(),
  themeMode: ThemeMode.system,
)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

brand Color
final

Static Methods

dark({Color? seed}) ThemeData
light({Color? seed}) ThemeData