LoginButton class
Botão de login estilo botão. Se options estiver vazio é um link simples (clicável); senão vira um botão expansível com as opções de login (dropdown).
- Inheritance
-
- Object
- Component
- StatelessComponent
- LoginButton
Constructors
-
LoginButton({required String label, String? href, List<
LoginOption> options = const [], Key? key}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String
-
final
-
options
→ List<
LoginOption> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited