FileLeadStore class

Armazenamento simples em arquivo (content/leads.jsonl), uma linha por lead.

Implemented types

Constructors

FileLeadStore({String path = 'content/leads.jsonl'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Lead lead) Future<void>
override
all() Future<List<Lead>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited