Feature class

Um recurso exibido na grade de features da landing (ícone + título + texto).

Constructors

Feature({required String icon, required String title, required String description})
const

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
icon String
Emoji ou caractere usado como ícone (sem depender de assets).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited