Lead class

Lead capturado pelo formulário de contato.

Constructors

Lead({required String name, required String email, String message = '', DateTime? createdAt})
const
Lead.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime?
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
message String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toJsonLine() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited