FlenxHeroSlide class

Um slide do hero/carrossel da loja.

Constructors

FlenxHeroSlide({required String title, required String ctaHref, String? eyebrow, String? subtitle, String? priceFrom, String? priceValue, String ctaLabel = 'aproveite', String? backgroundImage})
const

Properties

backgroundImage String?
URL da imagem de fundo do slide (com overlay escuro para legibilidade).
final
ctaHref String
final
ctaLabel String
final
eyebrow String?
final
hashCode int
The hash code for this object.
no setterinherited
priceFrom String?
final
priceValue String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited