FlenxAnimation enum

Tipos de animação disponíveis no FlenxAnimated.

Inheritance
Available extensions

Values

fadeIn → const FlenxAnimation

Fade in: opacidade 0 → 1.

slideUp → const FlenxAnimation

Slide de baixo para cima.

slideDown → const FlenxAnimation

Slide de cima para baixo.

slideLeft → const FlenxAnimation

Slide da direita para a esquerda.

slideRight → const FlenxAnimation

Slide da esquerda para a direita.

zoomIn → const FlenxAnimation

Zoom in: escala 0.9 → 1.

pulse → const FlenxAnimation

Pulso: aumenta e diminui levemente.

bounce → const FlenxAnimation

Pulo: sobe e desce.

float → const FlenxAnimation

Flutuação suave.

spin → const FlenxAnimation

Rotação contínua.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FlenxAnimation>
A constant List of the values in this enum, in order of their declaration.