FlenxRow class

Linha (horizontal) — como o Row do Flutter. Com wrap true, quebra para baixo quando a tela é estreita (responsivo automático, sem media query).

Inheritance

Constructors

FlenxRow(List<Component> children, {double gap = 0, FlenxAlign cross = FlenxAlign.center, FlenxAlign main = FlenxAlign.start, bool wrap = false, Key? key})
const

Properties

children List<Component>
final
cross FlenxAlign
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
main FlenxAlign
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wrap bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited