PageRequest class

Parâmetros de paginação de uma listagem (vêm de ?page e ?perPage).

Constructors

PageRequest({int page = 1, int perPage = 20})
const
PageRequest.fromQuery(Map<String, String> query, {int defaultPerPage = 20, int maxPerPage = 100})
Constrói a partir dos parâmetros de query, com limites sãos.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int
Limite por página (LIMIT).
no setter
offset int
Quantos registros pular no SQL (OFFSET).
no setter
page int
final
perPage int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited