FlenxRoute class
Uma rota do site: o SEO (meta) e o componente (builder) juntos — uma única definição alimenta o render, as meta tags, o sitemap e o llms.txt.
Constructors
- FlenxRoute(RouteMeta meta, FlenxPageBuilder builder, {bool island = false})
-
const
- FlenxRoute.island(RouteMeta meta, FlenxPageBuilder builder)
-
Atalho para rotas que são ilhas Flutter (widgets interativos).
const
Properties
- builder → FlenxPageBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- island → bool
-
true→ renderiza como ilha Flutter (injeta o bootstrap do Flutter).final - meta → RouteMeta
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited