Blog class
Facade do blog — ponto único de uso. Carrega os .md, monta a taxonomia,
expõe a fonte de rotas para o SEO e resolve qualquer caminho /blog* no
componente a ser renderizado. Cria um post = soltar um arquivo markdown.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
posts
→ List<
BlogPost> -
final
- routeSource → BlogRouteSource
-
Fonte de rotas para registrar no RouteRegistry (sitemap/llms/SEO).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taxonomy → Taxonomy
-
final
Methods
-
handles(
String path) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pageFor(
String path, {String? query, int page = 1}) → Component? -
Resolve o caminho no componente correspondente, ou
nullse não existir.queryé o termo de busca (/blog?q=...) epagea página (?page=N). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromSource(
BlogSource source) → Future< Blog> - Carrega o blog de UMA fonte qualquer (Markdown, banco, composta...).
-
fromSources(
List< BlogSource> sources) → Future<Blog> -
Carrega o blog de VÁRIAS fontes ao mesmo tempo (ex.:
.md+ banco). A ordem define a prioridade quando háslugrepetido (a primeira vence). -
load(
String directory) → Future< Blog> - Carrega o blog de uma pasta de arquivos markdown (no servidor).