Taxonomy class
Resultado da indexação taxonômica do blog: categorias e tags com seus posts.
Constructors
-
Taxonomy({required List<
CategoryArchive> categories, required List<TagArchive> tags}) -
const
Properties
-
categories
→ List<
CategoryArchive> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited