MarkdownBlogSource class
Fonte de posts em Markdown: arquivos .md em uma pasta do filesystem.
Mantém o fluxo clássico do Flenx (criar post = soltar um .md).
- Implemented types
Constructors
- MarkdownBlogSource(String directory, {BlogRepository repository = const BlogRepository()})
-
const
Properties
- directory → String
-
Pasta com os arquivos
.md(ex.:lib/content/blog).final - hashCode → int
-
The hash code for this object.
no setterinherited
- repository → BlogRepository
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
loadAll(
) → Future< List< BlogPost> > -
Carrega todos os posts desta fonte (sem ordenar/deduplicar — isso é
responsabilidade do agregador).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited