DbModel class
Definição declarativa de uma tabela: colunas (com notação de banco) e relações. É a fonte para gerar migration, queries e código Dart/PHP.
Constructors
Properties
-
columnNames
→ List<
String> -
Nomes de coluna (para INSERT/SELECT).
no setter
-
columns
→ List<
DbColumn> -
final
-
foreignKeys
→ List<
DbColumn> -
Colunas que são chave estrangeira.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryKey → DbColumn?
-
Coluna chave primária (ou
null).no setter -
relations
→ List<
DbRelation> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited