DbRegistry class
Registro do backend de banco. Você escolhe por DB_PROVIDER (supabase,
firebase, rest, jsonl...) e adiciona as credenciais — mesma ideia do
pagamento. Provedores novos entram com DbRegistry.register('x', ...).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromEnv(
Map< String, String> env, {Client? client}) → DbExecutor -
Escolhe o backend pelo
DB_PROVIDERdo ambiente (padrão:jsonl). -
register(
String name, DbExecutorFactory factory) → void -
Registra (ou substitui) um backend pelo nome usado em
DB_PROVIDER. -
resolve(
String provider, Map< String, String> env, {Client? client}) → DbExecutor