SqlType enum
Tipos de coluna suportados, mapeados para SQL (dialeto MySQL — comum em hospedagem PHP e no alvo Dart).
Values
- id → const SqlType
-
const SqlType('BIGINT') - integer → const SqlType
-
const SqlType('INT') - bigint → const SqlType
-
const SqlType('BIGINT') - boolean → const SqlType
-
const SqlType('TINYINT(1)') - decimal → const SqlType
-
const SqlType('DECIMAL(10,2)') - text → const SqlType
-
const SqlType('TEXT') - varchar → const SqlType
-
const SqlType('VARCHAR(255)') - datetime → const SqlType
-
const SqlType('DATETIME') - json → const SqlType
-
const SqlType('JSON')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sql → String
-
Tipo SQL correspondente (MySQL).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited