PageKind enum
Tipo semântico de uma página. Mapeia para og:type (Open Graph) e para o
@type do schema.org (JSON-LD), permitindo gerar dados estruturados certos.
Values
- website → const PageKind
-
const PageKind('website', 'WebPage') - article → const PageKind
-
const PageKind('article', 'Article') - blogPost → const PageKind
-
const PageKind('article', 'BlogPosting') - faq → const PageKind
-
const PageKind('website', 'FAQPage') - product → const PageKind
-
const PageKind('product', 'Product') - collection → const PageKind
-
const PageKind('website', 'CollectionPage') - profile → const PageKind
-
const PageKind('profile', 'ProfilePage')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - ogType → String
-
Valor para a meta tag
og:type.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaType → String
-
Valor para o
@typedo JSON-LD (schema.org).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited