SeoEndpoints class
Monta os endpoints de otimização servidos automaticamente pelo servidor:
/robots.txt, /sitemap.xml, /llms.txt e /llms-full.txt.
Todos derivam da mesma RouteRegistry — qualquer rota (estática ou dinâmica) adicionada ao registry aparece automaticamente em todos eles.
Constructors
- SeoEndpoints({required SeoConfig config, required RouteRegistry registry})
Properties
- config → SeoConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- registry → RouteRegistry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
mountOn(
Router router) → void -
Registra as rotas no
routershelf da aplicação. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited