BlogAdminPage class
Gerência de posts/notícias no admin: lista os posts do banco e abre o PostEditorPage para criar, editar ou excluir. Tela única reutilizável (news, demo) — alterna entre a lista e o editor.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BlogAdminPage
Constructors
- BlogAdminPage({AdminRestClient client = const AdminRestClient(), String listPath = '/api/blog/posts/list', String createPath = '/api/blog/posts', String updatePath = '/api/blog/posts/update', String deletePath = '/api/blog/posts/delete', String title = 'Notícias', String? defaultAuthor, Key? key})
-
const
Properties
- client → AdminRestClient
-
final
- createPath → String
-
final
- defaultAuthor → String?
-
Autor pré-preenchido em posts novos (ex.: o usuário logado do admin).
final
- deletePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- listPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- updatePath → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BlogAdminPage> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited