AppUser class
Usuário logado exibido no shell (área de user/admin e menu de perfil).
Constructors
Properties
- avatarUrl → String?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initials → String
-
Iniciais para o avatar quando não há imagem (ex.: "Ana Lima" → "AL").
no setter
- name → String
-
final
- role → String
-
Papel exibido (ex.: 'Administrador', 'Usuário').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited