DashboardStat class
Indicador do dashboard (ex.: Posts, Leads, Visitas).
Constructors
- DashboardStat({required IconData icon, required String label, required String value, required String trend})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited