FlenxBlogLayout class
Moldura pronta para as páginas de blog: header + rodapé + WhatsApp do site (SiteLayout) já com o CSS do blog injetado. Genérica e editável — passe a marca, os menus e o rodapé do seu site.
- Inheritance
-
- Object
- Component
- StatelessComponent
- FlenxBlogLayout
Constructors
-
FlenxBlogLayout({required Component child, required SiteBrand brand, List<
MenuLink> links = const [], List<LoginOption> loginOptions = const [], SiteConfig config = const SiteConfig(), Key? key}) -
const
Properties
- brand → SiteBrand
-
final
- child → Component
-
final
- config → SiteConfig
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
-
links
→ List<
MenuLink> -
final
-
loginOptions
→ List<
LoginOption> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited