SiteHeader class
Header de site institucional: somente top menu. Logo com link home, menu
customizável (itens clicáveis ou dropdowns expansíveis) e botão de login
(clicável ou expansível). Responsivo: vira hambúrguer (<details>) no mobile.
HTML puro + CSS (sem JS) — renderizado no servidor e indexável.
- Inheritance
-
- Object
- Component
- StatelessComponent
- SiteHeader
Constructors
-
SiteHeader({required SiteBrand brand, required List<
MenuLink> links, String loginLabel = 'Entrar', String? loginHref, List<LoginOption> loginOptions = const [], NavAlign align = NavAlign.right, Key? key}) -
const
Properties
- align → NavAlign
-
Alinhamento dos menus: à direita (padrão) ou centralizados.
final
- brand → SiteBrand
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
-
links
→ List<
MenuLink> -
final
- loginHref → String?
-
final
- loginLabel → String
-
final
-
loginOptions
→ List<
LoginOption> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited