FeaturesSection class

Seção de recursos — grade de cards (ícone, título, descrição), montada com o kit Dart (sem HTML/CSS). Textos e features são personalizáveis.

Inheritance

Constructors

FeaturesSection({required List<Feature> features, String eyebrow = 'Recursos', String title = 'Tudo que um site moderno precisa', String subtitle = 'Pré-configurado e pronto para produção — e 100% personalizável.', String id = 'servicos', FlenxCardHover? cardHover, String cardGlowColor = FlenxPalette.primary, bool animate = false, Key? key})
const

Properties

animate bool
Ativa scroll-reveal nas entradas do cabeçalho e em cada card.
final
cardGlowColor String
Cor do brilho quando cardHover é FlenxCardHover.glow.
final
cardHover FlenxCardHover?
Efeito de hover nos cards. null = sem hover.
final
eyebrow String
final
features List<Feature>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
final
title String
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited