MenuLink class
Item do menu de topo institucional. Pode ser um link simples (clicável) ou um item expansível (dropdown) quando tem children. Menu 100% customizável.
Constructors
Properties
-
children
→ List<
MenuLink> -
Subitens — se não vazio, o item vira dropdown expansível.
final
- external → bool
-
Abre em nova aba (
target=_blank) se externo.final - hashCode → int
-
The hash code for this object.
no setterinherited
- href → String?
-
Destino do link. Nulo quando é só o "pai" de um dropdown.
final
- isDropdown → bool
-
no setter
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited