SiteConfig class
Configuração central do site institucional: marca, nav, contato e WhatsApp.
Constructors
-
SiteConfig({SiteBrand brand = const SiteBrand(label: 'Site', homeHref: '/'), List<
MenuLink> links = const [], String loginLabel = 'Entrar', List<LoginOption> loginOptions = const [], String whatsappNumber = '5511999999999', String whatsappMessage = 'Olá! Vim pelo site e quero saber mais.', String leadAction = '/api/leads', String contactEmail = 'contato@flenx.dev'}) -
const
Properties
- brand → SiteBrand
-
final
- contactEmail → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leadAction → String
-
Endpoint que recebe o POST do formulário de leads.
final
-
links
→ List<
MenuLink> -
final
- loginLabel → String
-
final
-
loginOptions
→ List<
LoginOption> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- whatsappMessage → String
-
Mensagem pré-preenchida ao abrir o WhatsApp.
final
- whatsappNumber → String
-
Número no formato internacional, só dígitos (ex.: 55 + DDD + número).
final
- whatsappUrl → String
-
URL pronta do WhatsApp (wa.me) com a mensagem codificada.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited