FlenxText class

Texto — como o Text do Flutter, com estilo por parâmetros (nada de CSS).

Inheritance

Constructors

FlenxText(String data, {double size = 16, int weight = 400, String? color, FlenxTextAlign? align, double? maxWidthPx, double? lineHeight, FlenxAnimation? animation, int animationDelay = 0, int animationDuration = 600, Key? key})
const

Properties

align FlenxTextAlign?
final
animation FlenxAnimation?
Anima o texto com scroll-reveal. null = sem animação.
final
animationDelay int
final
animationDuration int
final
color String?
Cor em hex (ex.: FlenxPalette.ink). Nulo = herda.
final
data String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
lineHeight double?
final
maxWidthPx double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final
weight int
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited